@@ -1,6 +1,16 @@
 import sys
 import abstra.dashes as abstra_dashes
-from .hf import AuthResponse
+
+
+class AuthResponse:
+    """The response from the authentication process
+
+    Attributes:
+      email (str): The email address of the user
+    """
+
+    def __init__(self, email: str):
+        self.email = email
 
 
 def overload_stdio(broker):
@@ -26,4 +36,8 @@ def overload_abstra_sdk(broker):
             if type == "auth:validation-ended":
                 return AuthResponse(data["email"])
 
+    def redirect(url, query_params={}):
+        broker.send({"type": "redirect", "url": url, "queryParams": query_params})
+
     abstra_dashes.get_user = get_user
+    abstra_dashes.redirect = redirect
